/*****************************************************
Name:
   PROPARAY.C, Listing 4
File Type:
   Library
Description:
   Library file for managing arrays of window
   properties.  Analogous to the standard Windows
   functions GetProp, RemoveProp and SetProp, except
   they work on arrays of properties.
Function List
   GetPropArray
   RemovePropArray
   SetPropArray
Portability:
   MS Windows 3.1, MSC, BC
*****************************************************/

/* MS - Windows */
#include <windows.h>

/* Own */
#include <proparay.h>

/*****************************************************
Function Name:
   GetPropArray
Parameters:
   hWnd - window handle
   PropId
   Number - number of properties
   hProp - array of properties
Description:
   Retrives an array of properties previously set
   with the function SetPropArray.
*****************************************************/
void GetPropArray( HWND hWnd, int PropId, int Number,
      HANDLE FAR *hProp )
   {

   int iProp;

   for ( iProp = 0; iProp < Number; iProp++ )
      {
      hProp[iProp] = GetProp( hWnd,
         MAKEINTRESOURCE( PropId + iProp ));
      }

   }   /* function GetPropArray */


/*****************************************************
Function Name:
   RemovePropArray
Parameters:
   hWnd - window handle
   PropId - property id
   Number - number of properties
   hProp - array of properties
Description:
   Removes an array of properties previously set with
   the function SetPropArray.
*****************************************************/
void RemovePropArray( HWND hWnd, int PropId,
      int Number, HANDLE FAR *hProp )
   {

   int iProp;

   for ( iProp = 0; iProp < Number; iProp++ )
      {
      hProp[iProp] = RemoveProp( hWnd,
         MAKEINTRESOURCE( PropId + iProp ));
      }

   }   /* function RemovePropArray */


/*****************************************************
Function Name:
   SetPropArray
Parameters:
   hWnd - window handle
   PropId - property id
   Number - number of properties in array
   hProp - array of properites
Return:
   TRUE (SUCCESS) FALSE (FAIL)
Description:
   Associates an array of property with a window.
*****************************************************/
BOOL SetPropArray( HWND hWnd, int PropId, int Number,
      HANDLE FAR *hProp )
   {

   int iProp;

   for ( iProp = 0; iProp < Number; iProp++ )
      {
      if ( !SetProp( hWnd,
            MAKEINTRESOURCE( PropId ),
            hProp[iProp] ) )
         {
         for ( iProp--; iProp >= 0; iProp-- )
            {
            RemoveProp( hWnd, MAKEINTRESOURCE(
                  PropId + iProp ));
            }
         return ( FALSE );
         }
      }

   return ( TRUE );

   }   /* function SetPropArray */

/* End of PROPARAY.C */
